@@ -4,6 +4,9 @@
 # Main package name
 PACKAGE_NAME = "sensitivity"
 
+# Directory name of package
+PACKAGE_DIRECTORY = "sensitivity"
+
 # Name of Repo
 REPO_NAME = "sensitivity"
 
@@ -17,7 +20,7 @@ REPO_MAINTAINERS = [
 ]
 
 # Package version in the format (major, minor, release)
-PACKAGE_VERSION_TUPLE = (0, 2, 5)
+PACKAGE_VERSION_TUPLE = (0, 2, 6)
 
 # Short description of the package
 PACKAGE_SHORT_DESCRIPTION = "Python Sensitivity Analysis - Gradient DataFrames and Hex-Bin Plots"
@@ -61,7 +64,6 @@ PACKAGE_INSTALL_REQUIRES = [
     # 'otherpackage>=1,<2'
     'pandas>=1',
     'matplotlib',
-    'pd_utils',
     'IPython',
     'tqdm',
 ]
@@ -113,9 +115,12 @@ PACKAGE_URLS = {
     'Documentation': f'https://{REPO_USERNAME}.github.io/{REPO_NAME}'
 }
 
+# Url of logo
+PACKAGE_LOGO_URL = ""
+
 # Does not affect anything about the current package. Simply used for tracking when this repo was created off
 # of the quickstart template, so it is easier to bring over new changes to the template.
-_TEMPLATE_VERSION_TUPLE = (0, 5, 6)
+_TEMPLATE_VERSION_TUPLE = (0, 9, 2)
 
 if __name__ == '__main__':
     # Store config as environment variables
